=======
Credits
=======

Development Lead
----------------

* Scott Rothbarth <srserves85@gmail.com>

Contributors
------------

* Chas DeVeas <https://github.com/chasdevs>
* Ivan isenilov <https://github.com/isenilov>
* Ethan Schwab <https://github.com/ethan-schwab>
* Alejandro Jaramillo <https://github.com/irux>
* Jon Leung <https://github.com/jkleung11>